#
# spec file for package iproute2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _buildshell /bin/bash
Name:           iproute2
VCS: https://src.suse.de/SLFO-pool/iproute2#705721e9abda016556e0e74905dd9e669551f4920584d8abc6002b01bce4e682
Version:        6.3
Release:        slfo.1.1_1.2
Summary:        Linux network configuration utilities
License:        GPL-2.0-only
Group:          Productivity/Networking/Routing
URL:            https://wiki.linuxfoundation.org/networking/iproute2
# Using GPL-2.0 instead of GPL-2.0+ because of tc_skbedit.h and tc/q_multiq.c

#DL-URL:	https://kernel.org/pub/linux/utils/net/iproute2/
#Git-Clone: https://git.kernel.org/pub/scm/network/iproute2/iproute2.git/
#Git-Mirror:    https://github.com/shemminger/iproute2 ## not regularly updated
Source:         https://kernel.org/pub/linux/utils/net/iproute2/%name-%version.0.tar.xz
Source2:        https://kernel.org/pub/linux/utils/net/iproute2/%name-%version.0.tar.sign
Source3:        %name.tmpfiles
Source9:        %name.keyring
Patch1:         adjust-installation-directories-for-openSUSE-SLE.patch
Patch2:         use-sysconf-_SC_CLK_TCK-if-HZ-undefined.patch
Patch3:         add-explicit-typecast-to-avoid-gcc-warning.patch
Patch6:         split-link-and-compile-steps-for-binaries.patch
BuildRequires:  bison
BuildRequires:  db-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libbpf-devel
BuildRequires:  libelf-devel
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  xz
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(xtables) >= 1.4.11
Provides:       %name-doc = %version
Provides:       iproute = %version-%release
Provides:       %name(xfrm6_raw) = %version-%release
Obsoletes:      %name-doc < 4.15.0

%description
iproute2 is a collection of user-space utilities to set up networking
under Linux from the command-line. It can inspect and configure,
among other things: interface paramters, IP addresses, routing,
tunnels, bridges, packet transformations (IPsec, etc.), and Quality
of Service.

%package -n libnetlink-devel
Summary:        A Higher Level Interface to the Netlink Service
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Provides:       libnetlink = %version-%release

%description -n libnetlink-devel
libnetlink provides a higher-level interface to rtnetlink(7).
New programs should use libmnl-devel instead.

%package bash-completion
Summary:        Bash completion for iproute
License:        GPL-2.0-or-later
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
bash command line completion support for iproute.

%package arpd
Summary:        Userspace ARP daemon
License:        GPL-2.0-only
Group:          Productivity/Networking/Routing
Provides:       iproute2:/usr/sbin/arpd

%description arpd
The arpd daemon collects gratuitous ARP information, saving it on
local disk and feeding it to the kernel on demand to avoid redundant
broadcasting due to limited standard size (512..1024 entries,
depending on type) of the kernel ARP cache.

%prep
%autosetup -p1 -n %name-%version.0

find . -name *.orig -delete

%build
%global _lto_cflags %_lto_cflags -ffat-lto-objects
# build with -fPIC. For details see
# https://bugzilla.novell.com/show_bug.cgi?id=388021
xt_libdir="$(pkg-config xtables --variable=xtlibdir)"
xt_cflags="$(pkg-config xtables --cflags)"
%if 0%{!?make_build:1}
%define make_build make %{?_smp_mflags}
%endif
%make_build CCOPTS="-D_GNU_SOURCE %optflags -Wstrict-prototypes -Wno-error -fPIC -DXT_LIB_DIR=\\\"$xt_libdir\\\" $xt_cflags"

%install
b="%buildroot"
mkdir -p "$b/usr/bin" "$b/usr/sbin" "$b/sbin"
%make_install MODDESTDIR="$b/%_libdir/tc"

# We have m_xt instead
rm -f "$b/%_libdir/tc/m_ipt.so"

install -pm0644 "lib/libnetlink.a" "$b/%_libdir/"
chmod -x "$b/%_libdir/libnetlink.a"
install -pm0644 "include/libnetlink.h" "$b/%_includedir/"
chmod -x "$b/%_includedir/libnetlink.h"
install -Dm0644 "%SOURCE3" "$b/%_tmpfilesdir/%name.conf"
%if 0%{?suse_version} >= 1550
ln -sf "%_sbindir/ip" "$b/%_bindir/ip"
%else
ln -s "%_sbindir/ip" "$b/sbin/"
mkdir -p "$b/bin"
ln -sf "%_sbindir/ip" "$b/bin/ip"
%endif
for BIN in lnstat nstat routel ss; do
	ln -sf "%_sbindir/$BIN" "$b/%_bindir/$BIN"
done
mkdir -p "$b/%_docdir/%name"
cp -an README* examples/bpf "$b/%_docdir/%name/"

# bugzilla.opensuse.org/1205632
# You can't parse routel output anyway so it does not matter what we output
rm -v "$b/%_mandir/man8/routel.8"
cat >"$b/%_sbindir/routel" <<-EOF
	#!/bin/sh
	exec ip r l table all
EOF

%fdupes %buildroot/%_prefix

%post
%tmpfiles_create %_tmpfilesdir/%name.conf

%files
%_bindir/lnstat
%_bindir/nstat
%_bindir/routel
%_bindir/ss
%_sbindir/*
%_tmpfilesdir/%name.conf
%ghost %dir %_rundir/netns
%exclude %_sbindir/arpd
%if 0%{?suse_version} >= 1550
%_bindir/ip
%else
/sbin/*
/bin/ip
%endif
%_mandir/man7/*
%_mandir/man8/*
%exclude %_mandir/man8/arpd.8*
%dir %_sysconfdir/iproute2
%config(noreplace) %_sysconfdir/iproute2/*
%_libdir/tc/
%_datadir/tc/
%_docdir/%name/
%license COPYING

%files -n libnetlink-devel
%_includedir/*
%_mandir/man3/libnetlink*
%_libdir/lib*

%files bash-completion
%_datadir/bash-completion/

%files arpd
%_sbindir/arpd
%_mandir/man8/arpd.8*

%changelog
* Thu May  4 2023 info@paolostivanin.com
- Update to release 6.3:
  * New release of iproute2 corresponding to the 6.3 kernel.
    No large feature improvements only incremental improvements to
    the bridge mdb support, mostly just bug fixes.
- Rebase patches.
* Mon Mar 20 2023 jengelh@inai.de
- Delete xfrm-support-displaying-transformations-used-for-Mob.patch
  (mip6d-ng is abandoned too)
* Tue Mar  7 2023 jengelh@inai.de
- Update to release 6.2
  * f_flower: Introduce L2TPv3 support
  * bridge: fdb: Add support for locked FDB entries
  * bridge: link: Add MAC Authentication Bypass (MAB) support
  * ip: Support --json on `ip neigh get`
  * tc: Add JSON output to tc-class
* Tue Dec 27 2022 lnussel@suse.com
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Fri Dec 23 2022 dmueller@suse.com
- update to 6.1:
  * man: ss.8: fix a typo
  * testsuite: fix build failure
  * genl: remove unused vars in Makefile
  * json: do not escape single quotes
  * ip-monitor: Do not error out when RTNLGRP_STATS is not available
  * ip-link: man: Document existence of netns argument in add command
  * macsec: add Extended Packet Number support
  * macsec: add user manual description for extended packet number feature
  * ip: xfrm: support "external" (`collect_md`) mode in xfrm interfaces
  * ip: xfrm: support adding xfrm metadata as lwtunnel info in routes
  * ip: add NLM_F_ECHO support
  * libnetlink: add offset for nl_dump_ext_ack_done
  * tc/tc_monitor: print netlink extack message
  * rtnetlink: add new function rtnl_echo_talk()
  * ip: fix return value for rtnl_talk failures
  * iplink_bridge: Add no_linklocal_learn option support
  * devlink: use dl_no_arg instead of checking dl_argc == 0
  * devlink: remove dl_argv_parse_put
  * mnlg: remove unnused mnlg_socket structure
  * utils: extract CTRL_ATTR_MAXATTR and save it
  * devlink: expose nested devlink for a line card object
  * devlink: load port-ifname map on demand
  * devlink: fix parallel flash notifications processing
  * devlink: move use_iec into struct dl
  * devlink: fix typo in variable name in ifname_map_cb()
  * devlink: load ifname map on demand from ifname_map_rev_lookup() as well
  * dcb: unblock mnl_socket_recvfrom if not message received
  * libnetlink: Fix memory leak in __rtnl_talk_iov()
  * tc_util: Fix no error return when large parent id used
  * tc_util: Change datatype for maj to avoid overflow issue
  * ss: man: add missing entries for MPTCP
  * ss: man: add missing entries for TIPC
  * ss: usage: add missing parameters
  * ss: re-add TIPC query support
  * devlink: Fix setting parent for 'rate add'
  * link: display 'allmulti' counter
  * seg6: add support for flavors in SRv6 End* behaviors
  * tc: ct: Fix invalid pointer dereference
  * uapi: update from 6.1 pre rc1
  * u32: fix json formatting of flowid
  * tc_stab: remove dead code
  * uapi: update for in.h and ip.h
  * remove #if 0 code
  * tc: add json support to size table
  * tc: put size table options in json object
  * tc/basic: fix json output filter
  * iplink: support JSON in MPLS output
  * tc: print errors on stderr
  * ip: print mpls errors on stderr
  * tc: make prefix const
  * man: add missing tc class show
  * iplink_can: add missing `]' of the bitrate, dbitrate and termination arrays
  * ip link: add sub-command to view and change DSA conduit interface
* Tue Nov 22 2022 jengelh@inai.de
- Replace routel program by a non-python version [boo#1205632]
* Sat Oct  8 2022 gmbr3@opensuse.org
- update to 6.0:
  * ipstats: Add param.h for musl
  * Update kernel headers
  * libbpf: add xdp program name support
  * iplink: bond_slave: add per port prio support
  * seg6: add support for SRv6 Headend Reduced Encapsulation
  * lib: Introduce ppp protocols
  * f_flower: Introduce PPPoE support
* Wed Aug 10 2022 gmbr3@opensuse.org
- update to 5.19:
  * ip/iplink_virt_wifi: add support for virt_wifi
  * Update kernel headers
  * libnetlink: Add filtering to rtnl_statsdump_req_filter()
  * ipstats: Add a "set" command
  * ipstats: Add a group "link"
  * libbpf: Use bpf_object__load instead of bpf_object__load_xattr
  * uapi: change name for zerocopy sendfile in tls
  * bridge: vxlan device vnifilter support
  * f_flower: Add num of vlans parameter
* Sun Jun  5 2022 dmueller@suse.com
- update to 5.18:
  This is the release of iproute2 corresponding to the 5.18 kernel.
  There are not many new features in this release.
  * The build issues with libbpf should be fixed now.
  * Building with clang is now supported.
  * There are still some warnings with gcc-12 that will need to be
    fixed in the upstream kernel headers.
* Sat Mar 26 2022 gmbr3@opensuse.org
- update to 5.17:
  * lib/fs: fix memory leak in get_task_name()
  * bridge: Remove vlan listing from `bridge link`
  * bond: add arp_missed_max option
  * libnetlink: fix socket leak in rtnl_open_byproto()
  * dcb: Fix error reporting when accessing "dcb app"
  * tc_util: Fix parsing action control with space and slash
  * lib: fix ax25.h include for musl
  * uapi: add missing rose and ax25 files
  * rdma: Fix res_print_uint() and add res_print_u64()
  * tc: Add support for ce_threshold_value/mask in fq_codel
- Add tmpfiles.d conf for /run/netns
* Fri Mar  4 2022 gmbr3@opensuse.org
- Add eBPF(libbpf) support
- Adjust NETNS_RUN_DIR from /var/run to /run
* Tue Jan 11 2022 gmbr3@opensuse.org
- remove routef from links; it doesn't exist anymore
* Tue Jan 11 2022 gmbr3@opensuse.org
- update to 5.16:
  * devlink: Fix cmd_dev_param_set() to check configuration mode
  * ip: add AMT support
  * iplink_can: fix configuration ranges in print_usage() and add
    unit
  * tc: flower: Fix buffer overflow on large labels
  * ip/ipnexthop: fix unsigned overflow in parse_nh_group_type_res()
  * tc/m_vlan: fix print_vlan() conditional on TCA_VLAN_ACT_PUSH_ETH
  * iplink_can: add new CAN FD bittiming parameters:
    Transmitter Delay Compensation (TDC)
* Sat Nov 13 2021 dmueller@suse.com
- update to 5.15:
  * lib: bpf_legacy: fix bpffs mount when /sys/fs/bpf exists
  * man: devlink-port: fix the devlink port add synopsis
  * man: devlink-port: fix pfnum for devlink port add
  * iptuntap: fix multi-queue flag display
  * mptcp: unbreak JSON endpoint list
  * ipneigh: add support to print brief output of neigh cache in
    tabular format
  * ip/bond: add LACP active support
  * ip/tunnel: always print all known attributes
  * Add, show, link, remove IOAM namespaces and schemas
  * New IOAM6 encap type for routes
  * tc/skbmod: Introduce SKBMOD_F_ECN option
  * tc/f_flower: fix port range parsing
* Wed Sep  1 2021 jengelh@inai.de
- Update to release 5.14
  * ip: Add nodst option to macvlan type source
  * iplink: add support for parent device
  * iplink: support for WWAN devices
  * bridge: reorder cmd line arg parsing to let "-c" be detected
    as "color" option
* Wed Jul 28 2021 jengelh@inai.de
- Update to release 5.13
  * mptcp: add support for port-based endpoints
  * nexthop: Add ability to specify group type, add support for
    resilient nexthop groups and nexthop buckets
  * ip: xfrm: add support for tfcpad
  * ip-nexthop: support flush by id
  * mptcp: add support for event monitoring
  * bridge: monitor: add support for vlan monitoring
* Wed Apr 28 2021 info@paolostivanin.com
- Update to release 5.12
  * devlink: Use library provided string processing APIs
  * utils: Introduce helper routines for generic socket recv
  * q_cake: Fix incorrect printing of signed values in class statistics
  * json_print: Add print_tv()
  * nexthop: Add support for nexthop buckets
  * nexthop: Add support for resilient nexthop groups
  * ip: xfrm: add support for tfcpad
  * tc: e_bpf: fix memory leak in parse_bpf()
  * lib: bpf_legacy: treat 0 as a valid file descriptor
  * ip: drop 2-char command assumption
  * bridge: vlan: dump port only if there are any vlans
* Sat Mar  6 2021 jengelh@inai.de
- Update to release 5.11
  * tc: skip actions that don't have options attribute when
    printing
  * ip route: Print "trap" nexthop indication
  * dcb: new utility
* Wed Jan 27 2021 jengelh@inai.de
- Update to release 5.10
  * iplink: add support for protodown reason
  * ss: add support to expose various inet sockopts
  * ss: add support for XDP statistics
  * bridge: mdb: add support for source address
* Fri Dec  4 2020 lnussel@suse.de
- missed /usr/bin/ip link in usrmerge
* Sat Oct 17 2020 jengelh@inai.de
- Update to release 5.9
  * iplink: hsr: add support for creating PRP device similar to HSR
- Drop 0001-ip-add-error-reporting-when-RTM_GETNSID-failed.patch
  (merged)
* Fri Oct 16 2020 lnussel@suse.de
- prepare usrmerge (boo#1029961)
* Wed Sep 23 2020 jengelh@inai.de
- Add 0001-ip-add-error-reporting-when-RTM_GETNSID-failed.patch
* Wed Sep  2 2020 jengelh@inai.de
- Update to release 5.8
  * macsec: add support for MAC offload
  * Add support for mptcp netlink interface
  * erspan: Add type I version 0 support
* Wed Jun 17 2020 dmueller@suse.com
- remove bpf-bss-section-poc.patch, bpf-data-section-support-poc.patch:
  * these patches should be obsolete with cilium 1.7 and they never
  went upstream, so we can drop it (jsc#SLE-9813)
* Wed Jun  3 2020 jengelh@inai.de
- Update to release 5.7
  * macsec: add support for reporting and changing the offloading
    mode (`ip macsec offload`).
* Wed Apr  8 2020 kukuk@suse.com
- Move arpd into own subpackage to avoid libdb dependency
  [jsc#SLE-12189]
* Wed Apr  1 2020 jengelh@inai.de
- Update to release 5.6
  * ip link: show permanent hardware address
  * ip link: add support for STP xstats
  * ip link: bond: print LACP actor/partner oper states as strings
  * tc: Add support for ETS Qdisc
  * ip: xfrm: add espintcp encapsulation
  * tc: add support for FQ-PIE packet scheduler
* Sun Feb  9 2020 mkubecek@suse.cz
- Update to new upstream version 5.5
  * bridge: support fdb get
  * devlink: command line option to switch netns
  * devlink: all changing netns on reload
  * devlink: new timestamp format for health report dump
  * ip: support for alternative device names
  * ip link: support to get SR-IOV VF node GUID and port GUID
  * ip neigh: support get
  * rdma: relax requirement to have PID for HW objects
  * rdma: stat show mr
  * ss: allow dumping kTLS info
  * tc: support action flags
  * tc flower: support masked port destination and source match
  * tc pie: add dq_rate_estimator option
  * tipc: new commands to set TIPC AEAD key
  * more json support
- drop patches obsoleted by version upgrade:
  * ss-fix-end-of-line-printing-in-misc-ss.c.patch
  * no-double-definitions.patch
  * Revert-emp-fix-warning-on-deprecated-bison-directive.patch
  * Revert-tc-ematch-fix-deprecated-yacc-warning.patch
- refresh
  * split-link-and-compile-steps-for-binaries.patch
* Wed Jan  8 2020 jengelh@inai.de
- Add no-double-definitions.patch [boo#1160271]
* Tue Dec  3 2019 mkubecek@suse.cz
- Update to new upstream release 5.4
  * devlink: increase number of supported options (32 -> 64)
  * devlink: add trap set and show commands
  * devlink: add trap group set and show commands
  * devlink: add reset_dev_on_drv_probe param
  * devlink: support unknown value for fw_load_policy
  * devlink: support flash status monitoring
  * devlink: add reload failed indication
  * ip: netns: support dump of nsid conversion table
  * ip: nexthop: support filtering by protocol for flush and list
  * rdma: driver QP type string
  * tc: introduce ct action
  * tc: support 64-bit rate and peakrate
  * tc: etf: support skip_sock_check
  * tc: flower: add matching on conntrack info
  * tc: taprio: support setting flags
  * tc: taprio: support setting txtime_delay
  * documentation improvements
  * json output improvements
  * drop outdated example scripts and README files
- drop (patched script dropped)
  examples-fix-bashisms-in-example-script.patch
- ss-fix-end-of-line-printing-in-misc-ss.c.patch:
  fix missing end of line at the end of ss output
* Wed Sep 25 2019 mkubecek@suse.cz
- Update to new upstream release 5.3
  * devlink: show devlink port number
  * devlink: introduce PCI PF and VF port flavor and attribute
  * ip: support for nexthop objects
  * ip: add -Numeric option
  * ip: bond: support peer notification delay
  * rdma: query/set netns sharing sys parameter
  * rdma: support setting netns of rdma device
  * rdma: support "stat qp show"
  * rdma: support per-port counter mode
  * rdma: support stat manual mode
  * rdma: support default counter statistics
  * rdma: support CQ adaptive moderation
  * tc: support act_ctinfo action
  * tc: skbedit: add mask parameter
  * tc: add mpls actions
  * tc: stricter parameter parsing
  * tc: netem: json output
  * tipc: support interface name when activating UDP bearer
  * update documentation
- refresh
  * xfrm-support-displaying-transformations-used-for-Mob.patch
  * bpf-data-section-support-poc.patch
  * bpf-bss-section-poc.patch
- use fallback definition %%make_build if it is not defined
  (fix SLE12 build)
* Mon Aug 12 2019 mliska@suse.cz
- Use FAT LTO objects in order to provide proper static library.
* Fri Aug  2 2019 mliska@suse.cz
- Use %%make_build.
* Thu Jul 18 2019 mkubecek@suse.cz
- Update to new upstream release 5.2
  * devlink: increase column size for larger shared buffers
  * ip: reset netns after each command in batch mode
  * ip addr: do not set IPv6 specific options for IPv4 addresses
  * ip fou: support binding FOU ports
  * ip link: support bridge vlan_stats_per_port
  * ip link: support vlan bridge binding flag
  * ip macsec: supporet gcm-aes-256 cipher type
  * ip monitor: display interfaces from all groups
  * ip neigh: show neighbor offload indication
  * rdma: add link add/delete
  * rdma: update node type strings
  * ss: add option for single line output
  * ss: show raw numbers for data rates with --numeric
  * tc: support for plug qdisc
  * tc: taprio: support for changing schedules
  * tc: taprio: support cycle_time and cycle_time_extensions
  * tipc: support for link broadcast method and ratio
  * update documentation
* Mon May 13 2019 mkubecek@suse.cz
- Revert-tc-ematch-fix-deprecated-yacc-warning.patch:
  fix build on SLE12 and openSUSE Leap 42.3
* Mon May 13 2019 mkubecek@suse.cz
- Update to new upstream release 5.1
  * bridge: fdb: add support for src_vni option
  * devlink: report cell size
  * devlink: add dev info and dev flash subcommands
  * devlink: add health subcommand
  * ip link: display netrom link type
  * ip link: bond_slave: add xstats support
  * ip link: bridge: support mcast to unicast flag
  * ip netns: add attach subcommand to attach existing netns
  * ip xfrm: add option to hide keys in state output
  * ip xfrm: support xfrm interfaces
  * rdma: add unbound workqueue to list of poll context types
  * rdma: provide parent context index for all objects except CM_ID
  * rdma: add prefix for driver attributes
  * ss: support AF_XDP
  * tc: add hit counter for matchall
  * tc: add kind property to csum action
  * tc: q_cake: support fwmark option
  * improve batch and dump performance by caching link lookups
  * more JSON support
  * many text/JSON output fixes
* Sat Mar 23 2019 seanlew@opensuse.org
- Update to new upstream release 5.0.0
  * ip route: get print JSON output when -j is given
  * ip route: print route type in JSON output
  * tc: m_connmark: fix action error messages
  * ipaddress: print error messages on stderr
  * iprule: fix printing hint about unresolved iifname + oofname
  * man: Document COLORFGBG environment variable
  * tcpedit: Fix wrong pedit ipv6 structure id
  * ss: Render buffer to output every time a number of chunks alloc
  * ss: fix compilation under glibc < 2.18
* Wed Mar  6 2019 joe@cilium.io
- Add patches which enable support of BPF global data section,
  pulled from https://github.com/cilium/iproute2/tree/static-data
  * bpf-bss-section-poc.patch
  * bpf-data-section-support-poc.patch
* Sat Jan 26 2019 mkubecek@suse.cz
- Update to new upstream release 4.20
  * lwtunnel: allow src for encap ip/ip6
  * tc netem: add slot parameter
  * ip: add ipvtap support
  * ip neigh: support NTF_ROUTER and NTF_EXT_LEARNED flags
  * bridge fdb: support sticky flag
  * tc flower: geneve option match
  * tc: show TCA_STATS_BASIC_HW statistics
  * libnetlink: use correct message types for dump requests
  * tc flower: expose hardware offload count
  * tc: allow configuring taprio qdisc
  * bridge: support backup port
  * ss: support bytes_sent, bytes_retrans, dsack_dups, reord_seen
  * bridge: make -c match -compressvlans first instead of -color
  * fix build errors (old glibc, new llvm, no mnl, 32-bit archs)
  * various minor fixes
  * testsuite improvements
- refresh split-link-and-compile-steps-for-binaries.patch
* Tue Oct 30 2018 jengelh@inai.de
- Update to new upstream release 4.19
  * Support new features in Linux 4.19 such as the CAKE qdisc.
* Fri Aug 31 2018 mkubecek@suse.cz
- Update to new upstream release 4.18
  * tc: more JSON output
  * vxlan: fix ttl inherit behavior
  * gre/gre6: allow clearing {,i,o}{key,seq,csum} flags
  * bpf: don't offload perf array maps
  * tipc: Add support to set and get MTU for UDP bearer
  * tc: flower: add support for verbose logging
  * rdma: print driver resource attributes
  * devlink: introduce support for showing port flavours
  * ip address: Add support for address metric
  * ip route: print RTA_CACHEINFO if it exists
  * ip route get: support for sport, dport and ipproto match
  * ip route: Add support for a few routing protocols
  * ip address: strengthen check on 'label' input
  * ip: add rmnet initial support
  * tc: fix batch force option
  * ip address: Fix and make consistent label match handling
  * ip: add support for seg6local End.BPF action
  * lib/namespace: avoid double-mounting /sys
  * tc: flush output after each command in batch mode
  * ip link: don't stop batch processing
  * various command output fixes
  * documentation improvements
- rdma-sync-some-IP-headers-with-glibc.patch:
  drop (present in 4.18)
* Wed Aug  1 2018 mkubecek@suse.cz
- Update to new upstream release 4.17
  * use netlink rather than proc and sysfs for tunnels
  * man: document -json and -pretty options
  * ip, tc: JSON and color output for more subcommands
  * bridge: implement JSON and color output
  * tc: implement color output
  * rdma: Add batch command support
  * ss: print skmeminfo for packet sockets
  * ip: link_gre6.c: Support IP6_TNL_F_ALLOW_LOCAL_REMOTE flag
  * tc: support the ipt ematch
  * ip rule: let user see and use protocol keyword
  * rdma: update device capabilities flags (PCI write end padding)
  * tc: f_flower: Add support for matching first frag packets
  * bridge: add option extern_learn
  * ss: Add support for TIPC socket diag
  * tipc: introduce command for handling a new 128-bit node
    identity
  * tc: add oneline mode
  * rdma: ad PD, MR, CQ and CM_ID resource tracking information
  * rdma: Ignore unknown netlink attributes
  * ip/l2tp: remove offset and peer-offset options
  * ss: drop slabinfo based statistics
  * ip: don't lookup interface index until needed
  * rt_protos: drop old experimental gated names
  * ip: IFLA_NEW_NETNSID/IFLA_NEW_IFINDEX support
  * devlink: do not require NETLINK_{CAP,EXT}_ACK
  * ip: display netns name instead of nsid
  * ip link: enable to specify a name for the link-netns
- rdma-sync-some-IP-headers-with-glibc.patch:
  fix build on Leap 42.3 and SLE12
- utils-Do-not-reset-family-for-default-any-all-addres.patch:
  drop (present in 4.17)
- adjust-installation-directories-for-openSUSE-SLE.patch:
  refresh
- split-link-and-compile-steps-for-binaries.patch:
  refresh
* Wed May  2 2018 mkubecek@suse.cz
- utils-Do-not-reset-family-for-default-any-all-addres.patch:
  fix parsing of "ip route add default via <ipv6_address>" command
  (bsc#1091603)
* Tue Apr 10 2018 mkubecek@suse.cz
- Update to new upstream release 4.16
  * ip link: allow configuring GSO max values
  * gre6: add collect metadata support
  * erspan: add erspan version II support
  * ip link: add support for netdevsim device type
  * tc: Add batchsize feature for filter and actions
  * tc red: allow setting th_min and th_max to the same value
  * bpf: support map offload
  * tc: support shared block to share filters between qdiscs
  * ip tunnel: unify local/remote endpoint address printing
  * tc: JSON output for prio and RED
  * rdma: add option to provide "-" sign for the port number
  * rdma: add filtering infrastructure
  * rdma: add QP resource tracking information
  * netns: allow negative nsid
  * ignore -color when json output is requested
  * devlink: add support for devlink resource abstraction
  * devlink: add support for hot reload
  * ip route: treat "default" and "all"/"any" addresses differenty
  * ss: allow excluding a socket table from being queried
- use %%license for license file (bsc#1082318)
* Tue Mar  6 2018 dmueller@suse.com
- add provides/obsoletes for removed iproute2-doc subpackage
* Wed Feb  7 2018 avindra@opensuse.org
- Update to new upstream release 4.15.0
  * Add "show" subcommand to "ip fou"
  * Show 'external' link mode in output
  * bridge: vlan: support for per vlan tunnel info
  * gre6/tunnel: Output flowlabel after tclass
  * ila: support for configuring identifier and hook types
  * ila: support to configure checksum neutral-map-auto
  * ip6_gre: add support for ERSPAN tunnel
  * ip6tnl/tunnel: Output hoplimit before encapsulation limit
  * ip: add fastopen_no_cookie option to ip route
  * ip: bridge_slave: add neigh_suppress to the type help and
  * ip: bridge_slave: add support for per-port group_fwd_mask
  * ip: validate vlan value for vlan info
  * iplink: new option to set neigh suppression on a bridge port
  * link_iptnl: Print tunnel mode
  * qdisc: print offload indication
  * ss: Implement automatic column width calculation
  * ss: Introduce columns lightweight abstraction
  * ss: add AF_VSOCK support
  * ss: add missing path MTU parameter
  * ss: print tcpi_rcv_ssthresh
  * tc: Add support for the CBS qdisc
  * tc: bandwith limits can now be specified in %%.
  * {f, m}_bpf: don't allow specifying multiple bpf programs
- drop man-fix-documentation-references-in-manual-pages.patch
  * debian specific paths were removed altogether
- partial cleanup with spec-cleaner
- use https in urls
* Sun Dec 10 2017 jengelh@inai.de
- Remove iproute2-doc (removed upstream) and
  doc-revert-PDF-creation.patch .
* Fri Nov 17 2017 jengelh@inai.de
- Update to new upstream release 4.14.1
  * ss: distinguish between IPv4 and IPv6 wildcard sockets
  * bridge: this patch adds json support for bridge mdb show
  * tc actions: improved batching and time filtered dumping
  * iproute: add support for SRv6 local segment processing
  * ip: add new command line argument -json (mutually exclusive with -color)
  * gre: add support for ERSPAN tunnel
  * tc: m_ife: allow ife type to zero
  * tc: m_ife: print IEEE ethertype format
  * iproute: add support for seg6 l2encap mode
  * devlink: Add support for special format protocol headers
  * devlink: Add support for protocol IPv4/IPv6/Ethernet special formats
  * ss: detect IPPROTO_ICMPV6 sockets
  * tc/actions: introduce support for jump action
  * devlink: add batch command support
* Wed Sep  6 2017 mkubecek@suse.cz
- Update to new upstream release 4.13
  * extended ack support
  * ip monitor: support IFLA_EVENT
  * many BPF improvements
  * new command rdma
  * fixes for issues reported by Coverity
  * updated documentation and examples
  * bridge: distinguish between ext. learned vs offloaded FDBs
  * ip netns: make /var/run/netns bind-mount recursive
  * geneve: support for modifying geneve device
  * utils: return default family when rtm_family is not
    RTNL_FAMILY_IPMR/IP6MR
  * tc: m_tunnel_key: add csum/nocsum option
  * tc filter: add support for chain index
  * tc action: introduce support for goto chain action
  * tc: flower: add support for tcp flags
  * tc: add support for TRAP action
  * tc: flower: add support for matching on ip tos and ttl
  * ip: add support for GRE ignore-df knob
  * ip route get: extend to return matching fib route
  * ip route get: extend for mpls routes
  * ss: enclose IPv6 address in brackets
  * vti: print keys in hex not dotted notation
- Refresh
  adjust-installation-directories-for-openSUSE-SLE.patch
  split-link-and-compile-steps-for-binaries.patch
* Tue Aug 22 2017 mkubecek@suse.cz
- patch cleanup for SLE15 package:
  * rename iproute2-dirs.diff
  - > adjust-installation-directories-for-openSUSE-SLE.patch
  * split iproute2-HZ.diff into
    use-sysconf-_SC_CLK_TCK-if-HZ-undefined.patch and
    add-explicit-typecast-to-avoid-gcc-warning.patch
  * rename revert-pdf-creation.diff
  - > doc-revert-PDF-creation.patch
  * rename revert-bison-fix.diff
  - > Revert-emp-fix-warning-on-deprecated-bison-directive.patch
  * rename kernel_xfrm6_raw.patch
  - > xfrm-support-displaying-transformations-used-for-Mob.patch
  * refresh man-fix-documentation-references-in-manual-pages.patch
  * rename iproute2-split-make.patch
  - > split-link-and-compile-steps-for-binaries.patch
  * rename iproute2-3.16.0-fix-bashisms.patch
  - > examples-fix-bashisms-in-example-script.patch
- apply all patches in both specfiles to make sure everything is
  built from fully patched sources
- move SLE11 workarounds to the end of the series
* Tue Jul 11 2017 mkubecek@suse.cz
- Update to new upstream release 4.12
  * tc: add support for invisible qdisc dumping
  * ip route: support ttl-propagation attribute
  * ip route: support for MPLS LWT ttl attribute
  * libnetlink: add flag to suppress print of nlmsg error
  * ip netconf: show all address families by default
  * ip vrf: show command name next to pid
  * ip: add ip sr command to control SR-IPv6 internal structures
  * ip route: add support for SR-IPv6 lwtunnel encapsulation
  * ip link: expose packet marking atribute of tunnels
  * bpf: add support for generic xdp
  * ip xfrm: add xfrm state crypto offload
  * devlink: add support for pipeline debug (dpipe)
  * tc: reflect HW offload status
  * vxlan: add support for modifying vxlan device attributes
  * pedit: introduce IPv6 support
  * ip: add support for more MPLS labels
  * devlink: add option to set and show eswitch encapsulation support
  * ip: add handling for new CAN netlink interface
  * ip vrf: Add show command
  * ip link: add vxcan support
  * ip link: support gre6 encaplimit option
  * ip mroute: add table output to show command
  * ip neigh: allow flush FAILED neighbour entry
  * ip tunnel: add support for mpls/ip to ipip and sit tunnels
* Thu Jun 29 2017 jengelh@inai.de
- Update to new upstream release 4.11
  * ip: support UID range routing.
  * ss: Add inet raw sockets information gathering via netlink diag interface
  * ss: print new tcp_info fields: delivery_rate and app_limited
  * ss: print new tcp_info fields: busy, rwnd-limited, sndbuf-limited times
  * tc: flower: support matching on ICMP type and code
  * lwt: BPF support for LWT
  * Introduce ip vrf command
  * iplink: bridge: add support for displaying xstats
  * iplink: bridge_slave: add support for displaying xstats
  * ip: Add support for MPLS netconf
* Sat Jun 10 2017 meissner@suse.com
- split link and compile steps for binaries, so LDFLAGS and CFLAGS
  are not mixed so the the PIE default build work.
- Add iproute2-split-make.patch
* Tue Dec 13 2016 jengelh@inai.de
- Update to new upstream release 4.9
  * bridge: vlan: add support to display per-vlan statistics
  * tipc: add the ability to get UDP bearer options
  * tc: flower: Introduce vlan support
  * ss: output TCP BBR diag information
  * iptnl: add support for collect_md flag in IPv4 and IPv6 tunnels
  * ss: Support displaying and filtering on socket marks.
  * tc: fq: display unthrottle latency
  * ip link: Add support to configure SR-IOV VF to vlan protocol
    802.1ad (VST QinQ)
  * ip rule: add selector support
  * bridge: add support for the multicast flood flag
  * ip: update link types to show 6lowpan and ieee802.15.4 monitor
  * ss: Add support for SCTP protocol
  * iproute2: macvlan: add "source" mode
* Wed Nov 16 2016 jslaby@suse.com
- put lnstat nstat routef routel ss into /usr/bin so that users can
  actually run them
* Wed Nov 16 2016 glin@suse.com
- Add libelf-devel to BuildRequires to enable bpf object loading
* Mon Oct 17 2016 jengelh@inai.de
- Update to new upstream release 4.7
  * add support for VXLAN-GPE
  * ss: add SK_MEMINFO_DROPS display
  * devlink: implement shared buffer support
  * devlink: implement shared buffer occupancy control
  * ip, token: add del command
  * fq_codel: add per queue memory limit
  * ip: add MACsec support
  * ipaddress: Allow listing addresses by type
  * ip rule: Add support for l3mdev rules
  * ss: Add support to filter on device
  * ip link/addr/route: Add support for vrf keyword
  * bridge: add json support for bridge fdb/vlan show
- Update to new upstream release 4.8
  * ip: report IFLA_GSO_MAX_SIZE and IFLA_GSO_MAX_SEGS
  * tc: Add support for the matchall traffic classifier.
  * iptuntap: show processes using tuntap interface
* Sat May 21 2016 jengelh@inai.de
- Update to new upstream release 4.6
  * vxlan: add support to set flow label
  * tc, bpf: add new csum and tunnel signatures
  * tc, bpf: further improve error reporting
  * tc, bpf: add support for map pre/allocation
  * ip link: Add support for kernel side filtering
  * tc: introduce IFE action
  * add devlink tool
  * iplink: display IFLA_PHYS_PORT_NAME
* Sat Mar 26 2016 jengelh@inai.de
- Update to new upstream release 4.5
  * {f,m}_bpf: allow for sharing maps
  * geneve: add support for IPv6 link partners
  * geneve: add support for lwt tunnel creation and dst port selection
  * route: allow routes to be configured with expire values
  * iplink: support setting addrgenmode stable_secret
  * tipc: add peer remove functionality
  * tc, clsact: add clsact frontend
  * ss: support closing inet sockets via SOCK_DESTROY.
  * bridge: support for static and dynamic fdb entries
  * iplink: Support VF Trust
* Thu Jan 14 2016 mkubecek@suse.cz
- Update to new upstream release 4.4
  * tunnel code rework
  * add VRF support
  * add lightweight tunnel support
  * ila: Add support for ILA lwtunnels
  * f_bpf: allow for optional classid and add flags
  * m_bpf: don't require default opcode on ebpf actions
  * route: Add RTM_F_LOOKUP_TABLE flag and show table id
  * neigh: Add support for filtering dumps by master device
  * route: print addrgenmode stable_secret and fallback otherwise
  * tc: flower no need to specify the ethertype
  * geneve: add support for IPv6 link partners
  * neigh: device is optional for proxy entries
  * tunnel: determine tunnel address family from the tunnel type
  * addr: ignore EADDRNOTAVAIL errors during address flush operation
  * vxlan, gre: add support for collect metadata flag
  * route: ignore RTAX_HOPLIMIT of value -1
  * route: fix printing of locked entries
  * vxlan: Add support for remote checksum offload
  * documentation improvements
- man-fix-documentation-references-in-manual-pages.patch:
  replace Debian specific paths and package names with SUSE ones
* Wed Nov 11 2015 jengelh@inai.de
- Update to new upstream release 4.3
  * route: filter routes by family if so specified
  * ip: add `ip rule save/restore`
  * Manpage additions for tc filters
* Thu Sep 10 2015 jengelh@inai.de
- Update to new upstream release 4.2
  * route: add support to print 'linkdown' nexthop flag
  * addr: add support for brief output
  * ss: add support for segs_in and segs_out
  * ss: add support for bytes_acked & bytes_received
  * Add displaying VF traffic statistics
  * tc: add support for Flower classifier
  * GENEVE support
  * link: add ageing_time, stp_state and priority for bridge
  * bridge: mdb: add support for router add/del notifications
  monitoring
  * ss: print value of IPV6_V6ONLY socket option if set
* Wed Jul 15 2015 dimstar@opensuse.org
- Update to version 4.1.1:
  * tipc: make build conditional on having libmnl.
  * build: must honor pkg-config flags for libmnl.
  * include: add copy of tipc.h.
  * Fix MPLS support.
- Drop iproute2-tipc-headers.patch, iproute2-pkgconfig.diff
  (fixed upstream)
* Mon Jun 29 2015 mkubecek@suse.cz
- iproute2-tipc-headers.patch:
  fix build on systems with pre-3.16 kernel headers
- apply build fixes also in iproute2-doc.spec
* Sun Jun 28 2015 jengelh@inai.de
- Update to new upstream release 4.1
  * ip: support RFC4191 router preference
  * xfrm: add command for configuring SPD hash table
  * tipc: add new TIPC configuration tool
  * BPF support in tc
  * Lots of RED (tc scheduler) cleanup work
  * color option to ip command
- Add iproute2-pkgconfig.diff: work around continued ignorance of
  pkg-config
* Tue Jun 16 2015 jengelh@inai.de
- Update iproute2-dirs.diff to respect /usr/share/tc [bnc#934828]
* Mon Apr 13 2015 jengelh@inai.de
- Update to new upstream release 4.0
  * ip: route: add congestion control metric
  * vxlan: Group policy extension
  * tc: add support for BPF based actions
  * iproute2: bridge: support vlan range adds
  * ip xfrm: Allow to specify "all" option for monitor
  * ipnetns: allow to get and set netns ids
  * iplink: add support of IFLA_LINK_NETNSID attribute
  * Allow specifying bridge port STP state by name rather than number.
  * ip-monitor: allow to monitor ip rules
  * bridge link: add support to specify master
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 3.19
  * ip link: Add support for remote checksum offload to IP tunnels
  * can: Add support for CAN FD non-ISO feature
  * ss: Filter inet dgram sockets with established state by default
  * ip link: Fix crash on older kernels when showing VF devices
  * ss: Unify packet stats output from netlink and proc
  * ss: Unify unix stats output from netlink and proc
  * tc class: Show classes as ASCII graph
  * ip link: Add ipvlan support to the iproute2/ip util
- Add kernel_xfrm6_raw.patch to recognize more XFRM types
* Wed Jan  7 2015 jengelh@inai.de
- Update to new upstream release 3.18
  * Human readable output for `ip -s link` (ip -s -h link)
  * Permit filtering `ip monitor` events by device per "dev NAME".
  * Permit filtering `ip link` output by device per "master NAME",
  and by type per `type T` (e.g. type vlan).
  * Permit filtering `ip addr` output by flags like "tentative" and
  "-tentative".
* Sun Dec 28 2014 ledest@gmail.com
- fix bashisms in gaiconf script
- add patches:
  * iproute2-3.16.0-fix-bashisms.patch
* Tue Nov 25 2014 mkubecek@suse.cz
- Update to new upstream release 3.17
  * ip: allow to set ipv6 address generation mode
  * nstat: 64bit support on 32bit architectures
  * ip: don't require "name" keyword when adding device
  (3.16 regression)
  * ip: support of usec rtt in tcp_metrics
  * ip: allow to change slave options via type_slave
  * ip: add support for IPv6 VTI tunnels
  * tc: rsvp/tcindex/route classifier support for multiple actions
  * ip: print stats with "ip -s addr show"
- Add revert-bison-fix.diff:
  fix build on SLE11
* Sun Aug 10 2014 jengelh@inai.de
- Update to new upstream release 3.16
  * bridge: Add master device name to bridge fdb show
  * ip: check for missing dev arg when doing VF rate
  * Add support to configure SR-IOV VF minimum and maximum Tx rate
  through ip tool
* Wed Jul 16 2014 jengelh@inai.de
- Update to new upstream release 3.15
  * Support for HHF qdisc
  * Updates to bridge command
  * Lots of vxlan related changes
  * Details at http://lwn.net/Articles/601909/
* Fri Apr 25 2014 dmueller@suse.com
- split iproute2-doc subpackage into a separate spec to reduce
  rebuild times
- add pre_checkin.sh to sync version number between iproute2 and
  iproute2-doc
* Wed Apr 16 2014 jengelh@inai.de
- Update to new upstream release 3.14
  * ip link: support for High Availability Seamless Redundancy
  (HSR) network devices.
  * ip link: support for creating/deleting bonding devices
  * ip link: support for specifying interface indexes during
  creation of devices
  * tc/pkt_sched: add support for the "FQ" Fair Queue packet scheduler
  * tc: support for the BPF-based traffic classifier
  * tc, netem: support 64-bit quantity rate speeds
  * tc: support for the new "PIE" Proportional Integral controller
  Enhanced scheduler
  * ss: display PF_LOCAL-SOCK_SEQPACKET sockets as such rather than
  SOCK_DGRAM
  * ss: display zone names when so needed
  * ss: add support for retrieving SELinux contexts
* Mon Dec  9 2013 jengelh@inai.de
- Update to new upstream release 3.12
  * ip rule: add route suppression options
  * tc: support for the "fq" Fair Queue packet scheduler
  * tc: support 64-bit rate estimator statistics
  * GRE-over-IPv6 tunnel support
  * VXLAN IPV6 support
* Thu Sep 12 2013 jengelh@inai.de
- Update to new upstream release 3.11
  * Support for Linux 3.11
  * iptunnel: check SIT_ISATAP flag only for SIT tunnel
  * ss: show destination address for netlink sockets
  * ss: Get netlink sockets info via sock_diag
  * vxlan: Allow setting destination to unicast address
  * ss: add fastopen support
  * htb: report overhead attribute
  * ip: allow to specify mode for sit tunnels
  * ip: iplink_vlan: add 802.1ad support
  * iptuntap: allow creation of multi-queue tun/tap device
* Wed Sep 11 2013 werner@suse.de
- Make it build with latest TeXLive 2013
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 3.9.0
  * Support for managing the forwarding tables in Bridge and VXLAN.
- Remove 0001-build-resolve-compile-error-due-to-missing-include.patch
  (merged upstream)
- Signature verification for the package
* Mon Apr 15 2013 jengelh@inai.de
- Update to new upstream release 3.8.0
  * implement bridge mdb commands
  * add DOVE extensions
  * add `ip netns pids` and `ip netns identify`
  * tc netem: allow negative packet/cell overhead
  * support tunnels in `ip link type ipip|sit|ip6tnl`
- Add 0001-build-resolve-compile-error-due-to-missing-include.patch
* Thu Dec 13 2012 jengelh@inai.de
- Update to new upstream release 3.7.0
  * add support for tcp_metrics
  * iplink: Added support for the kernel IPoIB RTNL ops
  * ss: Get udp sockets info via sock-diag
  * tc: add canid ematch to ematch_map
  * vxlan support
* Tue Oct  9 2012 jengelh@inai.de
- Update to new upstream release 3.6.0
  * ss: report SK_MEMINFO_BACKLOG
  * tc: add ipset ematch
  * iplink: add support for num[tr]xqueues
  * iproute2: Add FDB print and update cmds for self and master
  * iproute: Add ability to save, restore and show the interfaces'
  addresses
  * iproute2: VTI support for ip link command
- Rename iproute2-libdir-1.diff to iproute2-dirs.diff, as it does
  more than just changing LIBDIR.
- Add revert-pdf-creation.diff, as the new PDF creation commands
  do not want to work with openSUSE 12.2 and before.
* Tue Sep 18 2012 werner@suse.de
- Make it build even without pdflatex, use latex+dvips, beside this
  iproute2-pdflatex.diff was documented, see my last entry from
  Jul 30 14:33:58 UTC 2012.
* Mon Sep 17 2012 idonmez@suse.com
- Add BuildRequires on texlive-dvips for openSUSE > 12.2 to fix
  Factory builds.
* Sat Sep  8 2012 jengelh@inai.de
- Update to new upstream release 3.5.1
  * ss: Report MSS from internal TCP information
  * ip: allow IPv6 addresses for l2tp local and remote parameters
  * tc: Support for tc_codel - Controlled Delay AQM
  * tc: Support for fq_codel - Fair Queue Codel AQM
  * tc-netem: Add support for ECN packet marking
- Remove undocumented iproute2-pdflatex.diff which breaks the
  build since using the iproute2-3.5.1 tarball
* Mon Jul 30 2012 werner@suse.de
- Make it build with modern pdflatex and TeXLive 2012 ... for this
  also sgmltools has to know about correct babel style usage
* Thu May 24 2012 jengelh@inai.de
- Update to new upstream release 3.4.0
  * for kernel 3.4
  * ss: use new INET_DIAG_SKMEMINFO option to get more memory
  information for tcp socket
  * ip: add ability to set link state
* Sat Mar 31 2012 bili@suse.com
- Distribute COPYING file for rpm(bnc#745225).
* Fri Mar 30 2012 jengelh@medozas.de
- Update to new upstream release 3.3.0
  * This release updates qdisc parameters in sfq and red, adds Netem
  extensions for shaping and for loss models, adds lots of manual
  page corrections, adds the QFQ scheduler and the LLDP-to-ethernet
  type table (along with support for processless network namespaces
  and L2TPv3 plus L2TP tunneling), improves RED options, and adds
  assorted bugfixes.
* Thu Mar  8 2012 rschweikert@suse.com
- Place ip binary in /usr tree (UsrMerge project)
- Fix permissions to eliminate rpmlint errors
* Sat Jan 14 2012 jengelh@medozas.de
- Update to new upstream release 3.2.0
  * L2TPv3 support
  * netem additions for loss models, improved RED options
* Sat Dec 31 2011 jengelh@medozas.de
- Update to new upstream release 3.1.0
  * ip: Add processless network namespace support
  * tc: Add QFQ scheduler
  * ss: display closed UDP sockets on `ss -ul`
  * ss: report ecnseen
  * Add L2TP support
* Fri Oct 21 2011 jengelh@medozas.de
- Clarify license for iproute2.spec (bnc#720282)
* Sat Sep 24 2011 jengelh@medozas.de
- Add patch iproute2-xt-detect.diff to address shipped Makefiles'
  failure to use pkg-config to locate libxtables, and thus
  reenable m_xt
* Fri Jul  8 2011 jengelh@medozas.de
- Update to new upstream release 2.6.39
  * support device group semantics
  * support listing devices by group
  * parse flag XFRM_POLICY_ICMP
  * CHOKe scheduler
  * macvlan/macvtap: support 'passthru' mode
  * tc: SFB flow scheduler
  * tc add mqprio qdisc support
  * xfrm security context support
  * allow to specify truncation bits on auth algo
  * fix unit conversion of rtt/rttvar/rto_min
  * support IFLA_TXQLEN in ip link command
- Remove iproute2-pdfdoc.diff: merged upstream
- Remove iproute2-memleak.diff: merged upstream
* Tue May 31 2011 jengelh@medozas.de
- Correct installation path of tc modules
- Restore symbol lookup in m_xt.so (bnc#679172)
- Add patches to make m_xt build with libxtables6
- Restore m_xt's module lookup (bnc#660554)
- Run spec-beautifier
* Mon May 30 2011 jengelh@medozas.de
- Disable building m_xt.so which has not been updated for
  iptables 1.4.11
* Wed Mar 23 2011 bphilips@novell.com
  Remove unneeded patches:
  * iproute2-warnings.diff bnc#34714
  Warnings no longer exist
  * iproute2-iptunnel-fclose.diff
  Process is dying no need to close file pointers
  * iproute2-ss-pclose.diff
  Process is dying no need to close file pointers
  * iproute2-flushcheckuid.diff
  Fixed upstream
  * iproute2-skbedit-memset.diff
  Fixed upstream 46a6573259f46f86eb0048a2c805b24ff4183fa6
* Tue Mar 22 2011 ms@suse.de
- Update to 2.6.38, fix for options process with ipt (bnc #679172)
- tidy up the package, spec file names, patch names, etc
* Wed Jan 12 2011 mt@suse.de
- Adopted ip route rtt,rttvar,rto_min metrics time unit to
  milliseconds as required by recent kernels (bnc#659746).
* Tue Jan 11 2011 jengelh@medozas.de
- Update to iproute2-2.6.37
  * Support for iptables >= 1.4.9
  * Support for GRE in XFRM
  * tc f_flow now knows rxhash
  * Support for macvtap "mode" parameter
  * tc ACT_CSUM support
  * added `ip route save` and `ip route restore` commands
- Spec file updates
  * Remove pointless AutoReqProv:on (that's the default)
  * Enable tc's m_xt
* Fri Dec  3 2010 ms@suse.de
- removed the fragtimeout patch because it breaks the rto_min
  setup. The fragtimeout patch also requires a kernel side
  modification which we don't ship since SLES9 (bnc #656667)
* Mon Nov 15 2010 jengelh@medozas.de
- Split documentation into its own subpackage, reducing the size
  of the main package by ~500K
* Wed Nov  3 2010 jengelh@medozas.de
- Update to iproute2-2.6.35+git9 for obtaining
  Linux 2.6.36-introduced features (no iproute2-2.6.36 tag yet)
  * Added RTA_MARK support (e.g. `ip route get ::1 mark 2`)
  * 64-bit interface statistics
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.35
  * Added support for multicast iprules
  * Speed up `ss -p`
  * Update ARP header type table
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.34
  * Fix build issues with flex 2.5
  * Detect 6rd tunnel scope
  * Added `ip tuntap` support (this practically obsoletes the
  "tunctl" package)
  * Added support for XFRM/SA by fwmark
  * Added initrwnd
- 2 patches integrated, thus dropped
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.33
  * Added 6rd support
  * Added macvlan options for bridge mode
  * Added support to mark packets in skbedit
  * Added oif classification support in iprule
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.31
  * Dropped equalize support
  * Fixed segfault when using garbage lladdr
  * Added new m_xt module for iptables-1.4.5
  * Added support for CAN
  * Allow ISATAP with stateless autoconfiguration
  * Added support for cgroup
  * Added support for monitoring neigh table activities
- 3 patches integrated, thus dropped
* Tue Feb 23 2010 jengelh@medozas.de
- add a patch to avoid tun tunnels being shown as "link/65534"
* Sat Dec 19 2009 jengelh@medozas.de
- enable parallel build
* Wed Nov 11 2009 ms@suse.de
- check effective UID instead of real UID in the flush
  permissions coding (bnc #554419)
* Fri Oct  9 2009 ms@suse.de
- added missing fclose to ss utility (bnc #543986)
* Wed Sep 16 2009 ms@suse.de
- fixed memory leak in read_igmp() function ip/ipmaddr.c (bnc #538996)
* Thu Sep 10 2009 ms@suse.de
- added support for monitoring neighbour tables (bnc #537906)
- added support for displaying type labels (bnc #537906)
* Fri Aug 28 2009 ms@suse.de
- added missing pclose (bnc #534912)
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Aug 12 2009 adrian@suse.de
- update to version 2.6.29-1
  * Support for lxc
* Tue Jul 28 2009 ms@suse.de
- make sure do_tunnels_list proc file descriptor will be
  closed after use or on proc read error (bnc #525834)
* Thu Feb 19 2009 ms@suse.de
- fixed ss utility to display inet6 addresses if requested
  with -6 or -f inet6 (bnc #473156)
* Tue Jan 27 2009 ms@suse.de
- fixed a bug in which the memory for the tc_skbedit struct was
  being used uninitialized to 0.  This patch corrects the issue
  by using a memset to 0 out the memory of the
  structure (bnc #438950)
* Thu Dec 11 2008 agruen@suse.de
- Change max length of the MAC address from 16 bytes to 32 bytes
  to accommodate infiniband (bnc#445014).
* Mon Oct 13 2008 ms@suse.de
- fixed compiler warnings (bnc #434714)
* Thu Sep 18 2008 hare@suse.de
- Add skbedit support for FCoE (FATE#303914)
- Add multiqueue support for FCoE (FATE#303914)
- Rename libnl to libnetlink-devel
- Fix IPPROTO_DCCP redefine
- rpmlint fixes
* Mon Jul 14 2008 ms@suse.de
- update to version 2.6.25
  * Fix off by one in nested attribute management.
  * netem potential dist table overflow
  * rto_min value display overflow
  * Overhead calculation is now done in the kernel.
  * libnetlink: don't spin forever on receive error
  * Protocol field on tc_filter is required by the kernel, provide it
  * Add missing prefix bit length for addrlabel
  * Do not strip binaries with `install`
  * In police, fix uninitialized "overhead" variable.
  * lots of documentation fixes
* Fri Jul 11 2008 ms@suse.de
- fixed RTM_NEWLINK check for older kernels (bnc #407954)
* Mon Jun 30 2008 ms@suse.de
- fixed 'tc qdisc' segmentation fault (bnc #404755)
* Thu May  8 2008 ms@suse.de
- compile libnetlink with -fPIC (bnc #388021)
* Wed Apr 16 2008 schwab@suse.de
- Don't strip binaries.
* Thu Oct 25 2007 ms@suse.de
- update to version 2.6.23, fixed (#336488)
  Reason for update:
  * The macvlan module, which got added to the kernel in version
    2.6.23, needs the new "ip link add" feature
  These patches add a rewritten version of Ben's macvlan driver, which
  allows to create virtual ethernet devices. The underlying device is
  put in promiscous mode and packets are demuxed based on MAC address.
  It behaves similar to bridge devices in that packets are visible on
  the real device before delivery to the macvlan driver. The driver
  supports all features of the underlying device except VLAN
  acceleration, this is currently very hard to support. I might look
  into this in the future.
  The main downside of this driver is that it adds another hook in
  netif_receive_skb, unfortunately that is unavoidable. When not
  compiled in the hook vanishes of course.
  Usage is simple:
    ip link add link eth0 type macvlan
  Will create a macvlan0 device with a random MAC address on top of
  eth0. No iproute patches are required.
* Tue Oct 16 2007 jdelvare@suse.de
- libnetlink.3 is now part of the upstream package, no need to
  include our own copy.
* Wed Jul 11 2007 ms@suse.de
- update to version 2.6.22, fixed (#288551)
  * Kim Woelders <kim@woelders.dk>, various useful fixups: compilation
  with old kernels, cross-compiling, "all" == "any" in prefix spec.
  * Collected from my disk, cleaned and packed to directory iproute2/misc/
    several utilities: ss, nstat, ifstat, rtacct, arpd and module tcp_diag.
    Writing some docs. me.
  * prepared patchlet for pidentd to use tcp_diag.
  * David Miller: 64bit (and even worse 64bit kernel/32 bit user :-) fixes
    to above. tcp_diag is merged to main tree.
  * Alexandr D. Kanevskiy <kad@blackcatlinux.com>: various flaws in ss
  * Alexandr D. Kanevskiy <kad@blackcatlinux.com>: oops, more aggressive caching
    of names opened old bugs: ip started to print garbage in some places.
  * Robert Olsson, rt_cache_stat. Renamed to rtstat.
  * An old bug in "ip maddr ls": reduntant empty lines in output.
    Seeing this crap for ages but lucky match of desire/ability to repair
    and a huff about this happened only today. :-)
  * "Mr. James W. Laferriere" <babydr@baby-dragons.com>
    doc: option to produce ps output for non-a4 and not only 2 pages/sheet.
  * Jamal's patch for ingres qdisc.
  * Bernd Eckenfels <ecki@lina.inka.de>: deleted orphaned bogus #include
    in include/utils.h.
  * Julian Anastasov <ja@ssi.bg>: uninitialized fields in nexthop
    producing funny "dead" nexthops in multipath routes.
    Stupid me, look at the first line in [010803]... Was it difficult to guess
    this that time? People blame for several months. :-)
    Special thanks to bert hubert <ahu@ds9a.nl> who raised the issue in netdev.
    Thanks and apologies to Terry Schmidt <terry@nycwireless.net>,
    Ruben Puettmann <ruben.puettmann@freenet-ag.de>,
    Mark Ivens <mivens@clara.net>.
  * willy tarreau <wtarreau@yahoo.fr>: "make install" target.
  * Tunable limit for sch_sfq. Patch to kernel activating this
    is about to be submitted. Reminded by Adi Nugroho <Adi@iNterNUX.co.id>
* Fri Apr 20 2007 aj@suse.de
- Use texlive for building.
* Mon Apr  2 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Thu Feb  8 2007 ms@suse.de
- fixed array size of name string in iptables.h (#243281)
  array of size IPT_FUNCTION_MAXNAMELEN - 1 is referenced
  at element IPT_FUNCTION_MAXNAMELEN - 1 which is outside the
  array bounds
* Mon Jan 29 2007 ms@suse.de
- fixed wrong IPT_LIB_DIR value and replaced the code by a
  dynamic check for the /usr/%%lib/iptables directory (#238886)
* Tue Nov  7 2006 ro@suse.de
- fix permissions for manpage
* Thu Jul 20 2006 ms@suse.de
- replaced static HZ define to dynamic:
  [#]ifndef HZ
  [#]define HZ sysconf(_SC_CLK_TCK)
  [#]endif
* Thu May 25 2006 schwab@suse.de
- Fix crash while resolving addresses.
* Mon Apr  3 2006 hvogel@suse.de
- fix flex input file to use uppercase STR to avoid conflicts.
  This prevented tc from being build [#162931]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 mrueckert@suse.de
- update to version 2.6.15-060110
* Tue Nov  8 2005 mmj@suse.de
- update to version 051107
* Sun Oct 23 2005 ro@suse.de
- fix filelist for libnlink
* Thu Oct 20 2005 mmj@suse.de
- update to version 051007
- fix buffer overflow in iproute.c [#129415] (thanks Richard, Marcus)
- don't strip stuff
* Wed Aug 17 2005 cthiel@suse.de
- update to version 050816 [#105087]
* Sat Aug  6 2005 dmueller@suse.de
- add /bin/ip symlink (#102513)
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Mon May  9 2005 mmj@suse.de
- Update to 2.6.11-050330
* Thu Feb 10 2005 ro@suse.de
- remove dropped tetex subpackages from nfb
* Fri Feb  4 2005 mmj@suse.de
- Update to 2.6.10-ss050124
* Tue Dec  7 2004 mmj@suse.de
- Don't trust that the kernel and do our own family check [#48600]
* Sun Oct 24 2004 mmj@suse.de
- Clean up spec file a bit
- Update to new snapshot including even more of our patches
* Tue Oct 12 2004 mmj@suse.de
- Update to 2.6.9 including some of our patches
* Tue Aug 17 2004 mmj@suse.de
- Make ip print correct type when printing stats [#42589]
* Wed Apr 21 2004 mmj@suse.de
- Fix bufferoverflow in nstat [#39179]
* Fri Apr 16 2004 kukuk@suse.de
- Fix compiling with 2.6.5 kernel headers
- Remove backup files
* Wed Apr 14 2004 mmj@suse.de
- Don't remove buildroot before install
* Wed Mar 17 2004 mmj@suse.de
- No executables below /usr/include [#36342]
* Wed Mar 10 2004 mmj@suse.de
- Olaf Kirch fixed the kernel, so remove the fix for [#35288]
* Wed Mar  3 2004 ak@suse.de
- Fix hang in ip addr flush (#35288)
* Wed Jan  7 2004 mmj@suse.de
- ifstat should store it's history in /var/tmp not /tmp
* Mon Nov 10 2003 mmj@suse.de
- Add more man-pages [#32981]
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
* Mon Aug 11 2003 mmj@suse.de
- Add all the pdf documentation [#28637]
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist
* Wed Jun  4 2003 kukuk@suse.de
- Don't use include-glibc directory
- Fix arpd to compile with db4
* Tue May 13 2003 mmj@suse.de
- Remove files we don't package
* Mon May 12 2003 mmj@suse.de
- Add glib-include from newer iputils, and change a kernel-include
  to make it build
* Tue Feb 11 2003 ug@suse.de
- patch for HTB support applied since 2.4.20 supports it
* Fri Feb  7 2003 mmj@suse.de
- Make the man tar-ball not contain gzipped man-pages, it's already
  compressed once.
- Apply patch from Andi Kleen for fragtimeout functionality
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
* Sun Oct 20 2002 mmj@suse.de
- Add manpages, thanks to ASPLinux [#21115]
* Wed Aug 21 2002 mmj@suse.de
- Added a patch to exit when regular user tries to flush routes or
  addresses. [#16000]
* Sun Aug 18 2002 ro@suse.de
- added ghostscript-x11-packages to neededforbuild (for gs)
* Mon Apr  8 2002 postadal@suse.cz
- updated to ss020116
  * added several utilities several utilities: ss, nstat, ifstat,
    rtacct, arpd and module tcp_diag
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 31 2002 ro@suse.de
- added libgimpprint to neededforbuild
* Tue Jan 29 2002 vinil@suse.cz
- /usr/lib -> %%_libdir
* Sun Jan 20 2002 vinil@suse.cz
- new version ss010824
- spec file cleanup
* Mon Nov 19 2001 bjacke@suse.de
- move ip to /sbin
- add iproute2 config files to /etc/
* Wed Oct 10 2001 stepan@suse.de
- fix compilation on ia64
* Tue Sep 18 2001 pthomas@suse.de
- Correct spelling in libnetlink.3
- Add both German and English descriptions for libnlink
* Mon Aug 27 2001 kukuk@suse.de
- Fix compiling on SPARC
* Tue Aug 21 2001 vinil@suse.cz
- new version ss010803
- get rid of kernel 2.2 patches
* Thu Jul 26 2001 kukuk@suse.de
- add glib to needed for build
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_x11> to <ghostscript-x11>
* Tue Jun 26 2001 ro@suse.de
- ETH_P_ECHO is apparently no longer defined
* Thu Mar  8 2001 uli@suse.de
- added xshared to neededforbuild
* Mon Mar  5 2001 kukuk@suse.de
- Remove bogus check for kernel header
* Fri Dec  1 2000 kukuk@suse.de
- Update to iproute2-2.2.4-now-ss001007 to fix compile problems
  with new kernel and glibc
* Mon Aug 28 2000 ak@suse.de
- fix permissions
- fix advmss/mtu confusion between 2.2 and 2.4 (advmss now works with 2.2
  kernels and is always enabled)
- add a new subrpm for libnetlink
- add libnetlink man page
* Tue Jul  4 2000 mha@suse.de
- new version (2.2.4-now-ss000305)
- new README.SuSE
- use ps2pdf instead of pdflatex, because the latter produces
  unusable pdf files for some reason
* Thu Jun  1 2000 vinil@suse.cz
- documentation enhancement
* Fri May 26 2000 vinil@suse.cz
- new version (ss000225)
- buildroot added
- sorted in group
* Thu Feb 17 2000 mha@suse.de
- new version (ss991023)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 22 1999 mha@suse.de
- new version
- renamed package iproute->iproute2, because that's how the author
  calls it
* Tue Jul 13 1999 ro@suse.de
- added psutils to neededforbuild
* Sun Jul 11 1999 mha@suse.de
- new package: iproute (tools for using the advanced routing options
    in kernel 2.2)
